@@ -21,9 +21,12 @@
 
 #include "comic.h"
 
+#include <QtCore/QPropertyAnimation>
 #include <QtCore/QTimer>
 #include <QtGui/QAction>
 #include <QtGui/QGraphicsLinearLayout>
+#include <QtGui/QGraphicsScene>
+#include <QtGui/QGraphicsView>
 #include <QtGui/QGraphicsSceneMouseEvent>
 #include <QtGui/QGraphicsSceneWheelEvent>
 #include <QtGui/QLabel>
@@ -38,7 +41,7 @@
 #include <KRun>
 #include <KTemporaryFile>
 
-#include "config-nepomuk.h"
+#include <config-nepomuk.h>
 #ifdef HAVE_NEPOMUK
 #include <Nepomuk/Resource>
 #include <Nepomuk/ResourceManager>
@@ -51,15 +54,12 @@
 
 #include <Plasma/Theme>
 #include <Plasma/Frame>
-#include <Plasma/Label>
 #include <Plasma/PushButton>
-#include <Plasma/TabBar>
 #include <plasma/tooltipmanager.h>
 
 #include "arrowwidget.h"
 #include "configwidget.h"
 #include "fullviewwidget.h"
-#include "fadingitem.h"
 #include "imagewidget.h"
 
 //NOTE based on GotoPageDialog KDE/kdegraphics/okular/part.cpp
@@ -105,10 +105,8 @@ class ChooseStripNumDialog : public KDialog
 };
 //END choose a strip dialog
 
-static const int s_tabHeight = 24;//used because there is no initial preferredHeight set
-
 ComicApplet::ComicApplet( QObject *parent, const QVariantList &args )
-    : Plasma::Applet( parent, args ),
+    : Plasma::PopupApplet( parent, args ),
       mShowPreviousButton( false ),
       mShowNextButton( false ),
       mShowComicUrl( false ),
@@ -117,134 +115,29 @@ ComicApplet::ComicApplet( QObject *parent, const QVariantList &args )
       mShowComicIdentifier( false ),
       mArrowsOnHover( true ),
       mMiddleClick( true ),
+      mMainWidget( 0 ),
       mFullViewWidget( 0 ),
       mActionShop( 0 ),
       mEngine( 0 ),
       mFrame( 0 ),
-      mFadingItem( 0 ),
+      mFrameAnim( 0 ),
       mPrevButton( 0 ),
-      mNextButton( 0 )
+      mNextButton( 0 ),
+      mZoomButton( 0 )
 {
     setHasConfigurationInterface( true );
-    setMinimumSize( QSizeF( 80, 40 ) );
     resize( 600, 250 );
     setAspectRatioMode( Plasma::IgnoreAspectRatio );
 
-    mTabBar = new Plasma::TabBar( this );
-    mTabBar->hide();
-    connect( mTabBar, SIGNAL( currentChanged( int ) ), this, SLOT( slotTabChanged( int ) ) );
+    setPopupIcon( "face-smile-big" );
 
-    mLabelTop = new Plasma::Label( this );
-    mLabelTop->setMinimumWidth( 0 );
-    mLabelTop->nativeWidget()->setWordWrap( false );
-    mLabelTop->nativeWidget()->setSizePolicy( QSizePolicy( QSizePolicy::Preferred, QSizePolicy::Fixed ) );
-    mLabelTop->setAlignment( Qt::AlignCenter );
-    mLabelTop->hide();
-
-    mImageWidget = new ImageWidget( this );
-    mImageWidget->setZValue( 0 );
-    mImageWidget->setSizePolicy( QSizePolicy( QSizePolicy::Expanding, QSizePolicy::Expanding ) );
-    mImageWidget->hide();
-
-    mLabelId = new Plasma::Label( this );
-    mLabelId->setMinimumWidth( 0 );
-    mLabelId->nativeWidget()->setWordWrap( false );
-    mLabelId->nativeWidget()->setCursor( Qt::PointingHandCursor );
-    mLabelId->nativeWidget()->setToolTip( i18n( "Jump to Strip ..." ) );
-    mLabelId->nativeWidget()->setSizePolicy( QSizePolicy( QSizePolicy::Preferred, QSizePolicy::Fixed ) );
-    mLabelId->hide();
-
-    mLabelUrl = new Plasma::Label( this );
-    mLabelUrl->setMinimumWidth( 0 );
-    mLabelUrl->nativeWidget()->setWordWrap( false );
-    if ( hasAuthorization( "LaunchApp" ) ) {
-        mLabelUrl->nativeWidget()->setCursor( Qt::PointingHandCursor );
-        mLabelUrl->nativeWidget()->setToolTip( i18n( "Visit the comic website" ) );
-    }
-    mLabelUrl->nativeWidget()->setSizePolicy( QSizePolicy( QSizePolicy::Preferred, QSizePolicy::Fixed ) );
-    mLabelUrl->hide();
-
-    mLeftArrow = new ArrowWidget( this );
-    mLeftArrow->setSizePolicy( QSizePolicy( QSizePolicy::Fixed, QSizePolicy::Expanding ) );
-    mLeftArrow->setCursor( Qt::PointingHandCursor );
-    mLeftArrow->hide();
-    mLeftArrow->setGeometry( QRectF( QPointF( 0, 0 ), mLeftArrow->preferredSize() ) );//to intially have a size -- needed in updateSize
-    connect( mLeftArrow, SIGNAL( clicked() ), this, SLOT( slotPreviousDay() ) );
-
-    mRightArrow = new ArrowWidget( this );
-    mRightArrow->setDirection( Plasma::Right );
-    mRightArrow->setSizePolicy( QSizePolicy( QSizePolicy::Fixed, QSizePolicy::Expanding ) );
-    mRightArrow->setCursor( Qt::PointingHandCursor );
-    mRightArrow->hide();
-    mRightArrow->setGeometry( QRectF( QPointF( 0, 0 ), mRightArrow->preferredSize() ) );//to intially have a size -- needed in updateSize
-    connect( mRightArrow, SIGNAL( clicked() ), this, SLOT( slotNextDay() ) );
-
-#ifdef HAVE_NEPOMUK
-    //for manually saving the comics
-    Nepomuk::ResourceManager::instance()->init();
-#endif
-}
-
-void ComicApplet::createLayout()
-{
-    QGraphicsLinearLayout *newLayout = new QGraphicsLinearLayout;
-    newLayout->setContentsMargins( 0, 0, 0, 0 );
-    newLayout->setSpacing( 1 );
-
-    QGraphicsLinearLayout *centralLayout = new QGraphicsLinearLayout;
-    centralLayout->setOrientation( Qt::Vertical );
-    centralLayout->setContentsMargins( 0, 0, 0, 0 );
-    centralLayout->setSpacing( 0 );
-
-    QGraphicsLinearLayout *bottomLayout = 0;
-
-    mLeftArrow->setVisible( mShowPreviousButton && !mArrowsOnHover );
-    if ( mLeftArrow->isVisible() ) {
-        newLayout->addItem( mLeftArrow );
-    }
-
-    mTabBar->setVisible( mShowTabBar && mUseTabs );
-    if ( mTabBar->isVisible() ) {
-        centralLayout->addItem( mTabBar );
-        centralLayout->setItemSpacing( centralLayout->count() - 1, 5 );
-    }
-
-    mLabelTop->setVisible( ( mShowComicAuthor || mShowComicTitle ) && !mLabelTop->text().isEmpty() );
-    if ( mLabelTop->isVisible() ) {
-        centralLayout->addItem( mLabelTop);
-    }
-
-    mImageWidget->show();
-    centralLayout->addItem( mImageWidget );
-
-    mLabelId->setVisible( mShowComicIdentifier && !mLabelId->text().isEmpty() );
-    mLabelUrl->setVisible( mShowComicUrl && !mLabelUrl->text().isEmpty() );
-    if ( mLabelId->isVisible() || mLabelUrl->isVisible() ) {
-        bottomLayout = new QGraphicsLinearLayout;
-        bottomLayout->setContentsMargins( 0, 0, 0, 0 );
-        bottomLayout->setSpacing( 0 );
-
-        if ( mLabelId->isVisible() ) {
-            bottomLayout->addItem( mLabelId );
-        }
-        bottomLayout->addStretch( 1 );
-        if ( mLabelUrl->isVisible() ) {
-            bottomLayout->addItem( mLabelUrl );
-        }
-        centralLayout->addItem( bottomLayout );
-    }
-    newLayout->addItem( centralLayout );
-
-    mRightArrow->setVisible( mShowNextButton && !mArrowsOnHover );
-    if ( mRightArrow->isVisible() ) {
-        newLayout->addItem( mRightArrow );
-    }
-
-    setLayout( newLayout );
+    graphicsWidget();
 }
 
 void ComicApplet::init()
 {
+    connect(this, SIGNAL(appletTransformedByUser()), this, SLOT(slotSizeChanged()));
+
     Plasma::ToolTipManager::self()->registerWidget( this );
 
     loadConfig();
@@ -299,8 +192,6 @@ void ComicApplet::init()
     mActions.append( mActionStorePosition );
     connect( mActionStorePosition, SIGNAL( triggered( bool ) ), this, SLOT( slotStorePosition() ) );
 
-    connect( this, SIGNAL( geometryChanged() ), this, SLOT( slotSizeChanged() ) );
-
     updateTabBar();
     changeComic( true );
 }
@@ -310,6 +201,96 @@ ComicApplet::~ComicApplet()
     delete mFullViewWidget;
 }
 
+QGraphicsWidget *ComicApplet::graphicsWidget()
+{
+    if ( !mMainWidget ) {
+        mMainWidget = new QGraphicsWidget( this );
+        mMainWidget->setMinimumSize( 150, 60 );
+        mMainWidget->setAcceptHoverEvents( true );
+        mMainWidget->installEventFilter( this );
+
+        QGraphicsLinearLayout *layout = new QGraphicsLinearLayout;
+        layout->setContentsMargins( 0, 0, 0, 0 );
+        layout->setSpacing( 0 );
+
+        QGraphicsLinearLayout *centralLayout = new QGraphicsLinearLayout;
+        centralLayout->setOrientation( Qt::Vertical );
+        centralLayout->setContentsMargins( 0, 0, 0, 0 );
+        centralLayout->setSpacing( 0 );
+
+        QGraphicsLinearLayout *bottomLayout = new QGraphicsLinearLayout;
+        bottomLayout->setContentsMargins( 0, 2, 0, 0 );
+        bottomLayout->setSpacing( 0 );
+
+        mTabBar = new ComicTabBar( mMainWidget );
+        mTabBar->nativeWidget()->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed );
+        mTabBar->hide();
+        connect( mTabBar, SIGNAL( currentChanged( int ) ), this, SLOT( slotTabChanged( int ) ) );
+        centralLayout->addItem( mTabBar );
+
+        mLabelTop = new ComicLabel( mMainWidget );
+        mLabelTop->setMinimumWidth( 0 );
+        mLabelTop->nativeWidget()->setWordWrap( false );
+        mLabelTop->nativeWidget()->setSizePolicy( QSizePolicy( QSizePolicy::Preferred, QSizePolicy::Fixed ) );
+        mLabelTop->setAlignment( Qt::AlignCenter );
+        mLabelTop->hide();
+        centralLayout->addItem( mLabelTop );
+        centralLayout->setItemSpacing( 1, 2 );
+
+        mImageWidget = new ImageWidget( mMainWidget );
+        mImageWidget->setZValue( 0 );
+        mImageWidget->setSizePolicy( QSizePolicy( QSizePolicy::Expanding, QSizePolicy::Expanding ) );
+        centralLayout->addItem( mImageWidget );
+
+        mLabelId = new ComicLabel( mMainWidget );
+        mLabelId->setMinimumWidth( 0 );
+        mLabelId->nativeWidget()->setWordWrap( false );
+        mLabelId->nativeWidget()->setCursor( Qt::PointingHandCursor );
+        mLabelId->nativeWidget()->setToolTip( i18n( "Jump to Strip ..." ) );
+        mLabelId->nativeWidget()->setSizePolicy( QSizePolicy( QSizePolicy::Preferred, QSizePolicy::Fixed ) );
+        mLabelId->hide();
+        bottomLayout->addItem( mLabelId );
+        bottomLayout->addStretch( 1 );
+
+        mLabelUrl = new ComicLabel( mMainWidget );
+        mLabelUrl->setMinimumWidth( 0 );
+        mLabelUrl->nativeWidget()->setWordWrap( false );
+        if ( hasAuthorization( "LaunchApp" ) ) {
+            mLabelUrl->nativeWidget()->setCursor( Qt::PointingHandCursor );
+            mLabelUrl->nativeWidget()->setToolTip( i18n( "Visit the comic website" ) );
+        }
+        mLabelUrl->nativeWidget()->setSizePolicy( QSizePolicy( QSizePolicy::Preferred, QSizePolicy::Fixed ) );
+        mLabelUrl->hide();
+        bottomLayout->addItem( mLabelUrl );
+        centralLayout->addItem( bottomLayout );
+
+        mLeftArrow = new ArrowWidget( mMainWidget );
+        mLeftArrow->setSizePolicy( QSizePolicy( QSizePolicy::Fixed, QSizePolicy::Expanding ) );
+        mLeftArrow->setCursor( Qt::PointingHandCursor );
+        mLeftArrow->hide();
+        connect( mLeftArrow, SIGNAL( clicked() ), this, SLOT( slotPreviousDay() ) );
+        layout->addItem( mLeftArrow );
+        layout->addItem( centralLayout );
+
+        mRightArrow = new ArrowWidget( mMainWidget );
+        mRightArrow->setDirection( Plasma::Right );
+        mRightArrow->setSizePolicy( QSizePolicy( QSizePolicy::Fixed, QSizePolicy::Expanding ) );
+        mRightArrow->setCursor( Qt::PointingHandCursor );
+        mRightArrow->hide();
+        connect( mRightArrow, SIGNAL( clicked() ), this, SLOT( slotNextDay() ) );
+        layout->addItem( mRightArrow );
+
+        mMainWidget->setLayout( layout );
+
+    #ifdef HAVE_NEPOMUK
+//         for manually saving the comics
+        Nepomuk::ResourceManager::instance()->init();
+    #endif
+    }
+
+    return mMainWidget;
+}
+
 void ComicApplet::dataUpdated( const QString&, const Plasma::DataEngine::Data &data )
 {
     setBusy( false );
@@ -328,6 +309,7 @@ void ComicApplet::dataUpdated( const QString&, const Plasma::DataEngine::Data &d
 
     mImage = data[ "Image" ].value<QImage>();
     mWebsiteUrl = data[ "Website Url" ].value<KUrl>();
+    setAssociatedApplicationUrls(mWebsiteUrl);
     mShopUrl = data[ "Shop Url" ].value<KUrl>();
     mNextIdentifierSuffix = data[ "Next identifier suffix" ].toString();
     mPreviousIdentifierSuffix = data[ "Previous identifier suffix" ].toString();
@@ -379,6 +361,11 @@ void ComicApplet::dataUpdated( const QString&, const Plasma::DataEngine::Data &d
     mLabelUrl->setText( mWebsiteUrl.host() );
     mImageWidget->setScaled( !mScaleComic );
 
+    mTabBar->setVisible( mShowTabBar && mUseTabs );
+    mLabelTop->setVisible( ( mShowComicAuthor || mShowComicTitle ) && !mLabelTop->text().isEmpty() );
+    mLabelId->setVisible( mShowComicIdentifier && !mLabelId->text().isEmpty() );
+    mLabelUrl->setVisible( mShowComicUrl && !mLabelUrl->text().isEmpty() );
+
     updateButtons();
     updateContextMenu();
 
@@ -387,11 +374,10 @@ void ComicApplet::dataUpdated( const QString&, const Plasma::DataEngine::Data &d
         toolTipData = Plasma::ToolTipContent( mAdditionalText, QString() );
         toolTipData.setAutohide( false );
     }
-    Plasma::ToolTipManager::self()->setContent( this, toolTipData );
+    Plasma::ToolTipManager::self()->setContent( mMainWidget, toolTipData );
 
     if ( !mImage.isNull() ) {
-        updateSize();
-        update();
+        QTimer::singleShot( 1, this, SLOT( updateSize()) );//HACK
     }
 }
 
@@ -426,8 +412,7 @@ void ComicApplet::createConfigurationInterface( KConfigDialog *parent )
 
 void ComicApplet::applyConfig()
 {
-    bool checkButtonBar = ( mArrowsOnHover != mConfigWidget->arrowsOnHover() );
-    bool differentComic = ( mComicIdentifier != mConfigWidget->comicIdentifier().at( 0 ) );
+    const bool differentComic = ( mComicIdentifier != mConfigWidget->comicIdentifier().at( 0 ) );
 
     mTabIdentifier = mConfigWidget->comicIdentifier();
     mComicIdentifier = mTabIdentifier.at( 0 );
@@ -439,7 +424,7 @@ void ComicApplet::applyConfig()
     mShowComicIdentifier = mConfigWidget->showComicIdentifier();
     mArrowsOnHover = mConfigWidget->arrowsOnHover();
     mMiddleClick = mConfigWidget->middleClick();
-    QTime time = mConfigWidget->tabSwitchTime();
+    const QTime time = mConfigWidget->tabSwitchTime();
     mSwitchTabTime = time.second() + time.minute() * 60 + time.hour() * 3600;
     mShowTabBar = !mConfigWidget->hideTabBar();
     mUseTabs = mConfigWidget->useTabs();
@@ -448,13 +433,9 @@ void ComicApplet::applyConfig()
     slotStartTimer();
     updateTabBar();
     saveConfig();
+    buttonBar();
 
     changeComic( differentComic );
-
-    if ( checkButtonBar ) {
-        buttonBar();
-        update();
-    }
 }
 
 void ComicApplet::changeComic( bool differentComic )
@@ -517,15 +498,21 @@ void ComicApplet::loadConfig()
     mMiddleClick = cg.readEntry( "middleClick", true );
     mScaleComic = cg.readEntry( "scaleToContent_" + mComicIdentifier, false );
     mMaxStripNum[ mComicIdentifier ] = cg.readEntry( "maxStripNum_" + mComicIdentifier, 0 );
-    mStoredIdentifierSuffix = cg.readEntry( "storedPosition_" + mComicIdentifier, "" );
-    mMaxSize = cg.readEntry( "maxSize", geometry().size() );
+    mStoredIdentifierSuffix = cg.readEntry( "storedPosition_" + mComicIdentifier, QString() );
+
+    //use a decent default size
+    const QSizeF tempMaxSize = isInPanel() ? QSizeF( 600, 250 ) : this->size();
+    mMaxSize = cg.readEntry( "maxSize", tempMaxSize );
     mLastSize = mMaxSize;
+
     mSwitchTabTime = cg.readEntry( "switchTabTime", 10 );// 10 seconds as default
     mShowTabBar = cg.readEntry( "showTabBar", true );
     mTabText = cg.readEntry( "tabText", QStringList( QString() ) );
     mComicTitle = mTabText.count() ? mTabText.at( 0 ) : QString();
     mUseTabs = cg.readEntry( "useTabs", false );
     mSwitchTabs = cg.readEntry( "switchTabs", false );
+    mSavingDir = cg.readEntry( "savingDir", QString() );
+    mOldSource = mComicIdentifier + ':' + mStoredIdentifierSuffix;
 
     buttonBar();
 }
@@ -546,6 +533,7 @@ void ComicApplet::saveConfig()
     cg.writeEntry( "tabText", mTabText );
     cg.writeEntry( "useTabs", mUseTabs );
     cg.writeEntry( "switchTabs", mSwitchTabs );
+    cg.writeEntry( "savingDir", mSavingDir );
 }
 
 void ComicApplet::slotChosenDay( const QDate &date )
@@ -597,7 +585,7 @@ void ComicApplet::slotReload()
 
 void ComicApplet::slotStartTimer()
 {
-    if ( mSwitchTabTime && mSwitchTabs ) {
+    if ( mUseTabs && mSwitchTabTime && mSwitchTabs && mTabIdentifier.count() > 1 ) {
         mReloadTimer->start( mSwitchTabTime * 1000 );
     } else {
         mReloadTimer->stop();
@@ -607,10 +595,11 @@ void ComicApplet::slotStartTimer()
 void ComicApplet::slotGoJump()
 {
     if ( mSuffixType == "Number" ) {
-        ChooseStripNumDialog pageDialog( 0, mCurrentIdentifierSuffix.toInt(), mFirstStripNum[ mComicIdentifier ], mMaxStripNum[ mComicIdentifier ] );
-        if ( pageDialog.exec() == QDialog::Accepted ) {
-            updateComic( QString::number( pageDialog.getStripNumber() ) );
+        QPointer<ChooseStripNumDialog> pageDialog = new ChooseStripNumDialog( 0, mCurrentIdentifierSuffix.toInt(), mFirstStripNum[ mComicIdentifier ], mMaxStripNum[ mComicIdentifier ] );
+        if ( pageDialog->exec() == QDialog::Accepted ) {
+            updateComic( QString::number( pageDialog->getStripNumber() ) );
         }
+        delete pageDialog;
         slotStartTimer();
     } else if ( mSuffixType == "Date" ) {
         KDatePicker *calendar = new KDatePicker;
@@ -635,8 +624,17 @@ void ComicApplet::slotStorePosition()
 void ComicApplet::slotSizeChanged()
 {
     // if the applet was resized manually by the user
-    if ( geometry().size() != mLastSize ) {
-        mMaxSize = geometry().size();
+    if ( isInPanel() ) {
+        if ( mMainWidget->size() != mLastSize ) {
+            mMaxSize = mMainWidget->size();
+            updateSize();
+
+            KConfigGroup cg = config();
+            cg.writeEntry( "maxSize", mMaxSize );
+        }
+    } else if ( this->geometry().size() != mLastSize ) {
+        mMaxSize = this->geometry().size();
+        updateSize();
 
         KConfigGroup cg = config();
         cg.writeEntry( "maxSize", mMaxSize );
@@ -654,101 +652,41 @@ void ComicApplet::slotShop()
     KRun::runUrl( mShopUrl, "text/html", 0 );
 }
 
-void ComicApplet::mousePressEvent( QGraphicsSceneMouseEvent *event )
+bool ComicApplet::isInPanel() const
 {
-    slotStartTimer();
-    if ( event->button() == Qt::LeftButton ) {
-        if ( mLabelUrl->isUnderMouse() ) {
-            if ( hasAuthorization( "LaunchApp" ) ) {
-                // link clicked
-                KRun::runUrl( mWebsiteUrl, "text/html", 0 );
-            }
-        } else if ( mLabelId->isUnderMouse() ) {
-            // identifierSuffix clicked clicked
-            slotGoJump();
-        } else if ( mImageWidget->isUnderMouse() && ( geometry().size() != mLastSize ) ) {
-            // only update the size by clicking on the image-rect if the user manual resized the applet
-            updateSize();
-        }
-    } else if ( ( event->button() == Qt::MidButton ) && mMiddleClick ) { // handle full view
-        if ( !mFullViewWidget ) {
-            mFullViewWidget = new FullViewWidget();
-        }
-
-        if ( !mFullViewWidget->isVisible() ) {
-            mFullViewWidget->setImage( mImage );
-            mFullViewWidget->adaptPosition( mapToScene( 0, 0 ).toPoint() );
-            mFullViewWidget->show();
-        }
-    }
-
-    event->ignore();
+    return ( this->geometry().width() < 70 ) || ( this->geometry().height() < 50 );
 }
 
-void ComicApplet::mouseReleaseEvent( QGraphicsSceneMouseEvent *event )
-{
-    if ( mFullViewWidget ) {
-        mFullViewWidget->hide();
-    }
-
-    Applet::mouseReleaseEvent( event );
-}
-
-void ComicApplet::wheelEvent( QGraphicsSceneWheelEvent *event ) {
-    slotStartTimer();
-    if ( mImageWidget->isUnderMouse() && ( event->modifiers() == Qt::ControlModifier ) ) {
-        const QPointF eventPos = event->pos();
-        const int numDegrees = event->delta() / 8;
-        const int numSteps = numDegrees / 15;
-
-        int index = mTabBar->currentIndex();
-        int count = mTabBar->count();
-        int newIndex = 0;
-
-        if ( numSteps % count != 0 ) {
-            if ( numSteps < 0 ) {
-                newIndex = ( index - numSteps ) % count;
-            } else if ( numSteps > 0 ) {
-                newIndex = index - ( numSteps % count );
-                newIndex = newIndex < 0 ? newIndex + count : newIndex;
-            }
-            mTabBar->setCurrentIndex( newIndex );
-        }
-        event->accept();
-    }
-    Applet::wheelEvent( event );
-}
-
-
 void ComicApplet::updateSize()
 {
-    //HACK to work around shortcomings in the layout code FIXME later
-    mLabelId->setPreferredWidth( mLabelId->nativeWidget()->sizeHint().width() );
-    mLabelUrl->setPreferredWidth( mLabelUrl->nativeWidget()->sizeHint().width() );
+    if ( configurationRequired() ) {
+        return;
+    }
 
-    //leftArea and rightArea are not completly correct when their size is smaller then the preferredSize
-    int leftArea = ( mShowPreviousButton && !mArrowsOnHover ) ? mLeftArrow->preferredSize().width() + 1 : 0;
-    int rightArea = ( mShowNextButton && !mArrowsOnHover ) ? mRightArrow->preferredSize().width() + 1 : 0;
-    int topArea = mTabBar->nativeWidget()->height() ? mTabBar->nativeWidget()->height() : s_tabHeight;
-    topArea = ( mShowTabBar && mUseTabs ) ? topArea + 5 : 0;
-    topArea += ( ( mShowComicAuthor || mShowComicTitle ) && !mLabelTop->text().isEmpty() ) ? mLabelTop->nativeWidget()->height() : 0;
-    int bottomArea = ( mShowComicUrl && !mLabelUrl->text().isEmpty() ) ? mLabelUrl->nativeWidget()->height() : 0;
-    bottomArea = ( mShowComicIdentifier && !mLabelId->text().isEmpty() ) ? mLabelId->nativeWidget()->height() : bottomArea;
-
-    QSizeF margins = geometry().size() - contentsRect().size();
-    QSizeF availableSize = mMaxSize - margins;
-    availableSize.setHeight( availableSize.height() - topArea - bottomArea );
-    availableSize.setWidth( availableSize.width() - leftArea - rightArea );
+    QSizeF notAvailableSize;
+    if ( isInPanel() ) {
+        notAvailableSize =  mMainWidget->geometry().size() - mImageWidget->size();
+    } else {
+        notAvailableSize =  this->geometry().size() - mImageWidget->size();
+    }
+    QSizeF availableSize = mMaxSize - notAvailableSize;
     mImageWidget->setAvailableSize( availableSize );
+    mLastSize = mImageWidget->preferredSize() + notAvailableSize;
 
-    mLastSize = mImageWidget->preferredSize() + margins;
-    mLastSize.setHeight( mLastSize.height() + topArea + bottomArea );
-    mLastSize.setWidth( mLastSize.width() + leftArea + rightArea );
+    if ( isInPanel() ) {
+        mMainWidget->resize( mLastSize );
+    } else {
+        resize( mLastSize );
+        mLastSize = this->size();//NOTE the applet won't be smaller than the minimum size of the MainWidget, thus the result of the resize might not correspond with mLastSize
+        emit sizeHintChanged( Qt::PreferredSize );
+        emit appletTransformedItself();
+    }
+    mImageWidget->update();
+}
 
-    createLayout();
-    resize( mLastSize );
-    emit sizeHintChanged(Qt::PreferredSize);
-    emit appletTransformedItself();
+QList<QAction*> ComicApplet::contextualActions()
+{
+    return mActions;
 }
 
 QSizeF ComicApplet::sizeHint(Qt::SizeHint which, const QSizeF &constraint) const
@@ -756,15 +694,15 @@ QSizeF ComicApplet::sizeHint(Qt::SizeHint which, const QSizeF &constraint) const
     if (which != Qt::PreferredSize) {
         return Applet::sizeHint(which, constraint);
     } else {
-        return mLastSize;
+        QSize imageSize = mImage.size();
+        if (!imageSize.isEmpty()) {
+            return imageSize;
+        } else {
+            return Applet::sizeHint(which, constraint);
+        }
     }
 }
 
-QList<QAction*> ComicApplet::contextualActions()
-{
-    return mActions;
-}
-
 void ComicApplet::updateComic( const QString &identifierSuffix )
 {
     //always stop the timer when changing the comic, as not all clicks are caught by mousePressEvent here
@@ -776,18 +714,17 @@ void ComicApplet::updateComic( const QString &identifierSuffix )
     if ( !mComicIdentifier.isEmpty() && mEngine && mEngine->isValid() ) {
         setBusy( true );
         const QString identifier = mComicIdentifier + ':' + identifierSuffix;
-        static QString oldSource = identifier;
 
         //disconnecting of the oldSource is needed, otherwise you could get data for comics you are not looking at if you use tabs
         //if there was an error only disconnect the oldSource if it had nothing to do with the error or if the comic changed, that way updates of the error can come in
-        if ( !mIdentifierError.isEmpty() && !mIdentifierError.contains(mComicIdentifier) ) {
+        if ( !mIdentifierError.isEmpty() && !mIdentifierError.contains( mComicIdentifier ) ) {
             mEngine->disconnectSource( mIdentifierError, this );
             mIdentifierError.clear();
         }
-        if ( ( mIdentifierError != oldSource ) && ( oldSource != identifier ) ) {
-            mEngine->disconnectSource( oldSource, this );
+        if ( ( mIdentifierError != mOldSource ) && ( mOldSource != identifier ) ) {
+            mEngine->disconnectSource( mOldSource, this );
         }
-        oldSource = identifier;
+        mOldSource = identifier;
 
         mEngine->disconnectSource( identifier, this );
         mEngine->connectSource( identifier, this );
@@ -799,6 +736,7 @@ void ComicApplet::updateComic( const QString &identifierSuffix )
             slotStartTimer();
         }
     } else {
+        kError() << "Either no identifier was specified or the engine could not be created:" << "id" << mComicIdentifier << "engine valid:" << ( mEngine && mEngine->isValid() );
         setConfigurationRequired( true );
         slotStartTimer();
     }
@@ -809,6 +747,9 @@ void ComicApplet::updateButtons()
     mShowNextButton = !mNextIdentifierSuffix.isEmpty();
     mShowPreviousButton = !mPreviousIdentifierSuffix.isEmpty();
 
+    mLeftArrow->setVisible( !mArrowsOnHover && mShowPreviousButton );
+    mRightArrow->setVisible( !mArrowsOnHover && mShowNextButton );
+
     if ( mNextButton && mPrevButton ) {
         mNextButton->setEnabled( mShowNextButton );
         mPrevButton->setEnabled( mShowPreviousButton );
@@ -840,12 +781,31 @@ void ComicApplet::slotSaveComicAs()
 
     KUrl srcUrl( tempFile.fileName() );
 
-    KUrl destUrl = KFileDialog::getSaveUrl( KUrl(), "*.png" );
+    QString dir = mSavingDir;
+    if ( dir.isEmpty() ) {
+        dir = KGlobalSettings::picturesPath();
+    }
+    if ( dir.isEmpty() ) {
+        dir = KGlobalSettings::downloadPath();
+    }
+    if ( dir.isEmpty() ) {
+        dir = QDir::homePath();
+    }
+
+    QString name = mComicTitle + " - " + mCurrentIdentifierSuffix + ".png";
+
+    KUrl destUrl = KUrl(dir);
+    destUrl.addPath( name );
+
+    destUrl = KFileDialog::getSaveUrl( destUrl, "*.png" );
     if ( !destUrl.isValid() ) {
         slotStartTimer();
         return;
     }
 
+    mSavingDir = destUrl.directory();
+    saveConfig();
+
 #ifdef HAVE_NEPOMUK
     bool worked = KIO::NetAccess::file_copy( srcUrl, destUrl );
     //store additional data using Nepomuk
@@ -878,31 +838,90 @@ void ComicApplet::slotSaveComicAs()
     slotStartTimer();
 }
 
-void ComicApplet::constraintsEvent( Plasma::Constraints constraints )
+bool ComicApplet::eventFilter( QObject *receiver, QEvent *event )
 {
-    if ( constraints && Plasma::SizeConstraint && mFrame ) {
-        QPointF buttons( ( size().width() - mFrame->size().width() ) / 2,
-                         contentsRect().bottom() - mFrame->size().height() - 5 );
-        mFrame->setPos( buttons );
-    }
-}
-
-void ComicApplet::hoverEnterEvent( QGraphicsSceneHoverEvent *event )
-{
-    if ( !configurationRequired() && mFadingItem && !mFadingItem->isVisible() ) {
-        mFadingItem->showItem();
+    if ( dynamic_cast<QGraphicsWidget *>(receiver) != mMainWidget ) {
+        return false;
     }
 
-    Applet::hoverEnterEvent( event );
-}
+    switch (event->type()) {
+        case QEvent::GraphicsSceneHoverLeave:
+            if ( mArrowsOnHover && mFrameAnim ) {
+                mFrameAnim->setDirection( QAbstractAnimation::Backward );
+                mFrameAnim->start();
+            }
 
-void ComicApplet::hoverLeaveEvent( QGraphicsSceneHoverEvent *event )
-{
-    if ( mFadingItem && mFadingItem->isVisible() ) {
-        mFadingItem->hideItem();
+            break;
+        case QEvent::GraphicsSceneHoverEnter:
+            if ( !configurationRequired() && mArrowsOnHover && mFrameAnim ) {
+                mFrameAnim->setDirection( QAbstractAnimation::Forward );
+                mFrameAnim->start();
+            }
+
+            break;
+        case QEvent::GraphicsSceneWheel:
+            {
+                slotStartTimer();
+                QGraphicsSceneWheelEvent *e = static_cast<QGraphicsSceneWheelEvent *>( event );
+                if ( mImageWidget->isUnderMouse() && ( e->modifiers() == Qt::ControlModifier ) ) {
+                    const QPointF eventPos = e->pos();
+                    const int numDegrees = e->delta() / 8;
+                    const int numSteps = numDegrees / 15;
+
+                    int index = mTabBar->currentIndex();
+                    int count = mTabBar->count();
+                    int newIndex = 0;
+
+                    if ( numSteps % count != 0 ) {
+                        if ( numSteps < 0 ) {
+                            newIndex = ( index - numSteps ) % count;
+                        } else if ( numSteps > 0 ) {
+                            newIndex = index - ( numSteps % count );
+                            newIndex = newIndex < 0 ? newIndex + count : newIndex;
+                        }
+                        mTabBar->setCurrentIndex( newIndex );
+                    }
+                    e->accept();
+                }
+            }
+            break;
+        case QEvent::GraphicsSceneMousePress:
+            {
+                slotStartTimer();
+                QGraphicsSceneMouseEvent *e = static_cast<QGraphicsSceneMouseEvent *>( event );
+                if ( e->button() == Qt::LeftButton ) {
+                    if ( mLabelUrl->isUnderMouse() ) {
+                        if ( hasAuthorization( "LaunchApp" ) ) {
+                            // link clicked
+                            KRun::runUrl( mWebsiteUrl, "text/html", 0 );
+                        }
+                    } else if ( mLabelId->isUnderMouse() ) {
+                        // identifierSuffix clicked clicked
+                        slotGoJump();
+                    } else if ( mImageWidget->isUnderMouse() && ( mMainWidget->geometry().size() != mLastSize ) ) {
+                        // only update the size by clicking on the image-rect if the user manual resized the applet
+                        updateSize();
+                    }
+                } else if ( ( e->button() == Qt::MidButton ) && mMiddleClick ) { // handle full view
+                    fullView();
+                }
+
+                e->ignore();
+            }
+            break;
+        case QEvent::GraphicsSceneResize:
+            if ( mFrame ) {
+                QPointF buttons( ( mMainWidget->size().width() - mFrame->size().width() ) / 2,
+                                mMainWidget->contentsRect().bottom() - mFrame->size().height() - 5 );
+                mFrame->setPos( buttons );
+            }
+
+            break;
+        default:
+            break;
     }
 
-    Applet::hoverLeaveEvent( event );
+    return false;
 }
 
 void ComicApplet::slotScaleToContent()
@@ -920,7 +939,7 @@ void ComicApplet::buttonBar()
 {
     if ( mArrowsOnHover ) {
         if ( !mFrame ) {
-            mFrame = new Plasma::Frame( this );
+            mFrame = new Plasma::Frame( mMainWidget );
             mFrame->setZValue( 10 );
             QGraphicsLinearLayout *l = new QGraphicsLinearLayout();
             mPrevButton = new Plasma::PushButton( mFrame );
@@ -929,6 +948,15 @@ void ComicApplet::buttonBar()
             mPrevButton->setMaximumSize( IconSize( KIconLoader::MainToolbar ), IconSize( KIconLoader::MainToolbar ) );
             connect( mPrevButton, SIGNAL( clicked() ), this , SLOT( slotPreviousDay() ) );
             l->addItem( mPrevButton );
+
+            mZoomButton = new Plasma::PushButton( mFrame );
+            mZoomButton->nativeWidget()->setIcon( KIcon( "zoom-original" ) );
+            mZoomButton->nativeWidget()->setToolTip( i18n( "Show at actual size in a different view.  Alternatively, click with the middle mouse button on the comic." ) );
+            mZoomButton->setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum );
+            mZoomButton->setMaximumSize( IconSize( KIconLoader::MainToolbar ), IconSize( KIconLoader::MainToolbar ) );
+            connect( mZoomButton, SIGNAL( clicked() ), this, SLOT( fullView() ) );
+            l->addItem( mZoomButton );
+
             mNextButton = new Plasma::PushButton( mFrame );
             mNextButton->nativeWidget()->setIcon( KIcon( "arrow-right" ) );
             mNextButton->setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum );
@@ -939,18 +967,42 @@ void ComicApplet::buttonBar()
             mFrame->setFrameShadow( Plasma::Frame::Raised );
             // To get correct frame size in constraintsEvent
             l->activate();
-            mFrame->hide();
-            mFadingItem = new FadingItem( mFrame );
-            mFadingItem->hide();
+            mFrame->setOpacity( 0.0 );
+
+            mFrameAnim = new QPropertyAnimation( mFrame, "opacity", mFrame );
+            mFrameAnim->setDuration( 100 );
+            mFrameAnim->setStartValue( 0.0 );
+            mFrameAnim->setEndValue( 1.0 );
+
             // Set frame position
             constraintsEvent( Plasma::SizeConstraint );
         }
     } else {
         delete mFrame;
         mFrame = 0;
+        mFrameAnim = 0;
         mPrevButton = 0;
         mNextButton = 0;
-        mFadingItem = 0;
+    }
+}
+
+void ComicApplet::fullView()
+{
+    if ( !mFullViewWidget ) {
+        mFullViewWidget = new FullViewWidget();
+    }
+
+    if ( !mFullViewWidget->isVisible() ) {
+        mFullViewWidget->setImage( mImage );
+        foreach (QGraphicsView *view, scene()->views()) {
+            if (view->sceneRect().contains(mMainWidget->pos())) {
+                QPoint viewPos = view->pos();
+                QPoint relPos = mapToScene( 0, 0 ).toPoint();
+                mFullViewWidget->adaptPosition( relPos + view->mapToGlobal(viewPos) );
+                break;
+            }
+        }
+        mFullViewWidget->show();
     }
 }
 
