@@ -92,7 +92,7 @@ void SlideShow::addImage(const QString &imagePath)
 
 void SlideShow::addDir(const QString &path, bool recursive)
 {
-    QDirIterator dirIterator(path, m_filters, QDir::Files, (recursive ? QDirIterator::Subdirectories : QDirIterator::NoIteratorFlags));
+    QDirIterator dirIterator(path, m_filters, QDir::Files, (recursive ? QDirIterator::Subdirectories | QDirIterator::FollowSymlinks : QDirIterator::NoIteratorFlags));
     QStringList dirPicturePaths;
 
     while (dirIterator.hasNext()) {
@@ -196,13 +196,14 @@ void SlideShow::clearPicture()
 
 void SlideShow::dataUpdated(const QString &name, const Plasma::DataEngine::Data &data)
 {
-    Q_UNUSED(name)
     if (data.isEmpty()) {
         m_image = QPixmap();
+        m_picture->setMessage(i18n("No Picture from this Provider."));
         return;
     }
 
-    m_image = data[0].value<QPixmap>();
+    m_image = data[name].value<QPixmap>();
+    m_picture->setMessage(QString());
     emit pictureUpdated();
 }
 
