@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007 Ivan Cukic <ivan.cukic+kde@gmail.com>
+ *   Copyright (C) 2007 Ivan Cukic <ivan.cukic(at)kde.org>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License version 2,
@@ -20,22 +20,24 @@
 #ifndef LANCELOTWINDOW_H
 #define LANCELOTWINDOW_H
 
+#include <QEvent>
+#include <QSignalMapper>
+#include <QTimer>
+
+#include <KConfig>
+#include <KConfigGroup>
+#include <KIcon>
+
 #include <plasma/svg.h>
 #include <plasma/plasma.h>
 #include <plasma/corona.h>
-#include <KConfig>
-#include <KConfigGroup>
-#include <QEvent>
-#include <QTimer>
-#include <QSignalMapper>
-
-#include <KIcon>
-#include "LancelotConfig.h"
-#include "ui_LancelotWindowBase.h"
 
 #include <lancelot/widgets/PopupList.h>
 #include <lancelot/widgets/PopupMenu.h>
 
+#include "LancelotConfig.h"
+#include "ui_LancelotWindowBase.h"
+
 namespace Lancelot {
     class ActionListModel;
     class ResizeBordersPanel;
@@ -97,6 +99,9 @@ protected Q_SLOTS:
      */
     void sectionActivated(const QString & item);
 
+private:
+    void nextSection(int increment);
+
 private Q_SLOTS:
     void systemButtonClicked();
 
@@ -202,8 +207,6 @@ private:
     KConfigGroup          m_mainConfig;
     QString               m_activeSection;
 
-    Lancelot::Instance  * instance;
-
     LancelotConfig m_configUi;
     QWidget * m_configWidget;
 
